/*
 * tune.cpp: Channelscan/-tune plugin for the Video Disk Recorder
 *
 * Plugin-Core
 *
 * (C) 2002 Mirko Gnther <mi.guenther@ib-helms.de>
 *
 * This code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * Or, point your browser to http://www.gnu.org/copyleft/gpl.html
 *
 */

//#include <vdr/plugin.h>
#include <vdr/interface.h>
//#include <vdr/menu.h>
#include "tune.h"
#include "i18n.h"
#include "scanMenu.h"
#include "scanThread.h"

static const char *VERSION        = "0.0.3";
static const char *DESCRIPTION    = "search and tune tv/radio channels";
static const char *MAINMENUENTRY  = "Tune";

const char* cPluginTune::Version(void)
{
 return VERSION;
}//const char* cPluginTune::Version(void)

const char* cPluginTune::Description(void)
{
 return tr(DESCRIPTION);
}//const char* cPluginTune::Description(void)

const char* cPluginTune::MainMenuEntry(void)
{
 return tr(MAINMENUENTRY);
}//const char* cPluginTune::MainMenuEntry(void)

cPluginTune::cPluginTune(void)
{
  // Initialize any member varaiables here.
  // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
  // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
  thread = NULL;
  menu   = NULL;
}

cPluginTune::~cPluginTune()
{
  // Clean up after yourself!
 if(thread) {
   thread->Stop();
   delete thread;
  }//if
}

const char *cPluginTune::CommandLineHelp(void)
{
  // Return a string that describes all known command line options.
  return NULL;
}

bool cPluginTune::ProcessArgs(int argc, char *argv[])
{
  // Implement command line argument processing here if applicable.
  return true;
}

bool cPluginTune::Start(void)
{
  // Start any background activities the plugin shall perform.
  RegisterI18n(Phrases);
  return true;
}

cOsdMenu *cPluginTune::MainMenuAction(void)
{
 menu = new cScanMenu(this);
 if(thread)
  thread->SetMenu(menu);
 return menu;
}

cMenuSetupPage *cPluginTune::SetupMenu(void)
{
  // Return a setup menu in case the plugin supports one.
  return NULL;
}

bool cPluginTune::SetupParse(const char *Name, const char *Value)
{
  // Parse your own setup parameters and store their values.
  return false;
}

void cPluginTune::GetNewThread()
{
 //thread->Stop();
 if(thread)
  delete thread;
 thread = new cScanThread;
 if(menu)
  thread->SetMenu(menu);
}//void cPluginTune::GetNewThread()

void cPluginTune::DelThread()
{
 delete thread;
 thread = NULL;
}//void cPluginTune::DelThread()

void cPluginTune::DelMenu()
{
 if(thread)
  thread->DelMenu();
}//void cPluginTune::DelMenu()

bool cPluginTune::hasThread()
{
 return (thread)?true:false;
}//bool cPluginTune::hasThread()

bool cPluginTune::StartThread()
{
 if(thread)
  return thread->Start();
 else return false;
}//bool cPluginTune::StartThread()

bool cPluginTune::runThread()
{
 if(thread)
  return thread->Active();
 else return false;
}//bool cPluginTune::runThread()

VDRPLUGINCREATOR(cPluginTune); // Don't touch this!
